"use strict";
/**
 * decorator of an event
 * @param  {string}            eventName the name of the event to listen
 * @return {PropertyDecorator}           PropertyDecorator
 */
function event(eventName) {
    return function (target, propertyKey) {
        (target.constructor.events || (target.constructor.events = {}))[eventName] = propertyKey;
    };
}
exports.event = event;
/**
 * decorator of a prop
 * @param  {PropOption}        options the option for the prop
 * @return {PropertyDecorator}         PropertyDecorator
 */
function prop(options) {
    return function (target, propertyKey) {
        (target.constructor.props || (target.constructor.props = {}))[propertyKey] = options;
    };
}
exports.prop = prop;
/**
 * decorator of a watch function
 * @param  {string}            path the path or the expression to observe
 * @return {PropertyDecorator}      PropertyDecorator
 */
function watch(path) {
    return function (target, propertyKey) {
        (target.constructor.watch || (target.constructor.watch = {}))[path] = propertyKey;
    };
}
exports.watch = watch;
